import { TCountry } from "@/types/type";
import Image from "next/image";

type Props = {
    country: TCountry | null;
    borderCountries: TCountry[];
};

export const CountriesInfo = ({ country, borderCountries }: Props) => {
    if (!country) return <div>Choose country</div>;

    const flagUrl = country.flags.png || "/placeholder.png";
    const flagAlt = country.flags.alt || country.name.common;

    return (
        <div>
            <div>
                <h2>Country: {country.name.common}</h2>
                <Image src={flagUrl} alt={flagAlt} width={300} height={150} />
            </div>
            <ul>
                <li>capital: {country.capital}</li>
                <li>area: {country.area}</li>
                <li>region: {country.region}</li>
            </ul>
            <ul>
                {borderCountries.map((c, index) => (
                    <li key={index}>{c.name.common}</li>
                ))}
            </ul>
        </div>
    );
};
